@@ -1,12 +1,14 @@
+from requests import request
 from rest_framework.response import Response
 
-from xj_payment.models import PaymentOrder
+from xj_payment.models import PaymentPayment
 
 
 class PaymentService:
-    def create(self, data):
+    @staticmethod
+    def create(data):
         print(data)
-        payment_order = PaymentOrder.objects.create(**data)
+        payment_order = PaymentPayment.objects.create(**data)
         return Response({
             'err': 0,
             'msg': '',
